#!/usr/bin/gnuplot -persist
#  
#    	G N U P L O T
#    	Version 4.0 patchlevel 0
#
#	Standard Settings for GPI
#       (c) 2005 Michael Goerz
#       http://www.physik.fu-berlin.de/~goerz/gp1/plotsettings_en.html
#
# See http://t16web.lanl.gov/Kawano/gnuplot/index-e.html
# for a good introduction to Gnuplot
#
# remember the 'help' command


# To save the plot to a postscript file, use
set terminal postscript enhanced
set output 'out.ps'


unset key
set tics in
set ticslevel 0.5
set ticscale 1 0.5
set mxtics 10
set mytics 10
set nox2tics
set noy2tics
set fit noerrorvariables
set grid xtics mxtics ytics mytics noztics nomztics

# If you want logscale, change this to 'set'
# You can use 'xlogscale', 'ylogscale', 'xylogscale'
unset logscale y

# If you want to, get can get rid of the right and top border axes:
# set border 3
# set xtics nomirror
# set ytics nomirror


# *************************************************************************

# This is an example for the following scenario:
# The datafile contains three blocks, separated by blank lines, each line 
# has the x value, the x error, the y value, and the y error separated by tabs
# the first block contains good data points, which will be used for the fit,
# the second block contains bad data, which will be plotted, but not used for
# the fit, and the third block contains two data points that describe the worst
# fit. The total plot will consist of the good data points, plotted as dots with
# xyerrorbars, the bad data points, plotted as circles with xyerrorbars, a best
# fit through the good data, and a worst fit, as a dashed line.
# The data is in data.csv


set title "Damped Oscillation (Damping Level 1)"
set xlabel "t  /  sec"
set ylabel "Amplitude  /  V"

# To set the plot ranges, use the following
# First look at the automatic output, then adjust manually
set xrange [0:30]
# set yrange [-0.3:0.3]


plot "damped1_orig.csv" with lines linetype 1 linewidth 1


# 'with' can be lines, dots, points, linespoints, impulses, steps, boxes,
#  xerrorbars, yerrorbars, xyerrorbars, vector, ...

# To plot an interpolated line between data points, you could use
# plot "data.csv" using 1:2 notitle with points, \
#      "data.csv" using 1:2 smooth csplines \


#    EOF
